import{t as r,a,b as i,u as c,f as p,g as d,_,h as u,k as l,T as h,P as f,C as g,M as y,s as m,i as b,j as s,l as v,m as w,n as k}from"./registerWidgets.59747b32.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c16309a7-6640-4182-887c-712a63d27645",e._sentryDebugIdIdentifier="sentry-dbid-c16309a7-6640-4182-887c-712a63d27645")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.0b51f570.js"),["assets/Player.0b51f570.js","assets/index.135ae79e.js","assets/registerWidgets.59747b32.js","assets/registerWidgets.efc6a450.css","assets/uuid.b94404db.js","assets/broker.3d7c8f8c.js","assets/passwordlessManager.794d3db6.js","assets/pubsub.cfb8c19f.js","assets/storage.e0256989.js","assets/Passwordless.af9fa329.js","assets/CircularLoading.eebf6e84.js","assets/lottie.15d20c75.js","assets/CircularLoading.f81b57b4.css","assets/icons.8e518be5.js","assets/Passwordless.86ac0c56.css","assets/executeJs.977da00c.js","assets/PlayerNavbar.6a6dc5eb.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.60776a12.js","assets/Steps.998aa76d.css","assets/Modal.9da25f39.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.2536274d.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.a3a0153d.js","assets/broker.a17a9f70.css","assets/DashPlayer.7acd2b33.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.1d4b957f.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});h.init(),D.init(),e.use(o),e.use(f),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.26afcafe.js.map
