import{S as c}from"./Sidebar.d8472947.js";import{N as m}from"./Navbar.8faa2659.js";import{C as p,D as d,E as l}from"./icons.8e518be5.js";import{d as u,ey as b,F as _,a as f,b as g,c as v,e as t,er as y,bw as z,t as w}from"./registerWidgets.59747b32.js";import{a as h}from"./asyncComputed.1d4b957f.js";import"./gateway.6a881856.js";import{O as I}from"./organization.216e97a2.js";import"./index.e8afc474.js";import"./Tooltip.b505a13d.js";import"./logo.084e5d7c.js";import"./passwordlessManager.794d3db6.js";import"./pubsub.cfb8c19f.js";import"./storage.e0256989.js";import"./activeRecord.e2c0e940.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7db3c055-553b-4f8c-a80c-b9852e5fa566",e._sentryDebugIdIdentifier="sentry-dbid-7db3c055-553b-4f8c-a80c-b9852e5fa566")}catch{}})();const O={class:"organization"},D=u({__name:"Organization",setup(e){const n=b().params.organizationId,{result:o}=h(()=>I.get(n)),r=_(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:d,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(k,x)=>{const s=f("router-view");return g(),v(z,null,[t(m,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const G=w(D,[["__scopeId","data-v-51ce7239"]]);export{G as default};
//# sourceMappingURL=Organization.86754b50.js.map
