import{d as u,ey as f,F as b,b as y,u as g,bu as _}from"./registerWidgets.59747b32.js";import{a as w}from"./asyncComputed.1d4b957f.js";import"./gateway.6a881856.js";import{M as s}from"./member.e6ea7189.js";import"./index.e8afc474.js";import{C as I}from"./CrudView.37ea6d3f.js";import"./passwordlessManager.794d3db6.js";import"./pubsub.cfb8c19f.js";import"./storage.e0256989.js";import"./activeRecord.e2c0e940.js";import"./DropdownMenu.7b5d814a.js";import"./Modal.9da25f39.js";import"./LoadingIndicator.04199c7c.js";import"./lottie.15d20c75.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="de794f61-28dd-45e4-863e-8df081d74097",e._sentryDebugIdIdentifier="sentry-dbid-de794f61-28dd-45e4-863e-8df081d74097")}catch{}})();const N=u({__name:"Members",setup(e){const r=f().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(r,t.email),c()},{loading:d,result:l,refetch:c}=w(()=>s.list(r)),p=b(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=l.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{N as default};
//# sourceMappingURL=Members.176f5e30.js.map
