import{t,b as d,c as s}from"./registerWidgets.59747b32.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="fdb5257d-fbb1-4de1-bcf5-229d1cd1341b",e._sentryDebugIdIdentifier="sentry-dbid-fdb5257d-fbb1-4de1-bcf5-229d1cd1341b")}catch{}})();const o={},r={class:"organization-settings"};function c(e,n){return d(),s("div",r,"Organization settings")}const a=t(o,[["render",c]]);export{a as default};
//# sourceMappingURL=OrganizationSettings.5be62ad2.js.map
