import{d as r,r as c,o as d,eM as l,b,c as f,eA as u,eR as p}from"./registerWidgets.59747b32.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="305ec193-0baf-4cd2-ab03-0b95e5bb50ec",e._sentryDebugIdIdentifier="sentry-dbid-305ec193-0baf-4cd2-ab03-0b95e5bb50ec")}catch{}})();const m=r({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=c(null);return d(()=>{s.value&&o.action.setElement(s.value),l.addAction(o.action)}),(a,t)=>(b(),f("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=i=>n("click")),onKeydown:t[1]||(t[1]=p(i=>n("click"),["enter"]))},u(a.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.a3a0153d.js.map
