import{M as r}from"./Modal.9da25f39.js";import{d as a,E as c,r as d,a as _,b as f,c as l,e as n,eq as i,bw as m,er as u,t as p}from"./registerWidgets.59747b32.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2fc80f49-145f-4e19-8349-df0a05146105",e._sentryDebugIdIdentifier="sentry-dbid-2fc80f49-145f-4e19-8349-df0a05146105")}catch{}})();const y=["src"],b=a({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,w)=>{const s=_("router-view");return f(),l(m,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,y)]),_:1},512)],64)}}});const x=p(b,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.0bc9a08a.js.map
