import{L as t}from"./lottie.15d20c75.js";import{d as a,r,o as d,b as s,c,er as i,c2 as _,t as l}from"./registerWidgets.59747b32.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="65b9c9ec-d2f1-4049-9fa2-3ebc4deace36",n._sentryDebugIdIdentifier="sentry-dbid-65b9c9ec-d2f1-4049-9fa2-3ebc4deace36")}catch{}})();const u={class:"container"},f=a({__name:"LoadingIndicator",setup(n){const e=r(null);return d(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(s(),c("div",u,[i("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const g=l(f,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.04199c7c.js.map
