import{u as a}from"./icons.8e518be5.js";import{d as c,a as r,b as i,c as d,e as _,bu as f,bh as l,t as u}from"./registerWidgets.59747b32.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8794e886-1c43-4906-ac35-ff8e402ccf2d",e._sentryDebugIdIdentifier="sentry-dbid-8794e886-1c43-4906-ac35-ff8e402ccf2d")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.33e2a4bf.js.map
