import{P as r}from"./Passwordless.af9fa329.js";import{d as a,ex as i,b as d,c as f,e as s,eq as c,t as _}from"./registerWidgets.59747b32.js";import{M as m}from"./member.e6ea7189.js";import{W as p}from"./WidgetsFrame.2536274d.js";import"./CircularLoading.eebf6e84.js";import"./lottie.15d20c75.js";import"./icons.8e518be5.js";import"./passwordlessManager.794d3db6.js";import"./pubsub.cfb8c19f.js";import"./storage.e0256989.js";import"./gateway.6a881856.js";import"./activeRecord.e2c0e940.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="350432fb-4624-4eff-826c-3dbf948a0883",e._sentryDebugIdIdentifier="sentry-dbid-350432fb-4624-4eff-826c-3dbf948a0883")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=i();async function t(n){await m.login(),o.push({name:"home"})}return(n,b)=>(d(),f("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:c(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const C=_(u,[["__scopeId","data-v-0e3dc783"]]);export{C as default};
//# sourceMappingURL=Login.a53a7a63.js.map
